@@ -1,13 +1,13 @@
 package CGI::Session;
 
-# $Id: /local/cgi-session/trunk/lib/CGI/Session.pm 273 2006-02-16T03:30:35.734419Z mark  $
+# $Id: /local/cgi-session/trunk/lib/CGI/Session.pm 286 2006-03-09T03:07:01.898465Z mark  $
 
 use strict;
 use Carp;
 use CGI::Session::ErrorHandler;
 
 @CGI::Session::ISA      = qw( CGI::Session::ErrorHandler );
-$CGI::Session::VERSION  = '4.05';
+$CGI::Session::VERSION  = '4.06';
 $CGI::Session::NAME     = 'CGISESSID';
 $CGI::Session::IP_MATCH = 0;
 
@@ -182,7 +182,7 @@ sub flush {
     my $self = shift;
 
     return unless $self->id;            # <-- empty session
-    return if $self->{_STATUS} == 0;    # <-- neither new, nor deleted nor modified
+    return if !defined($self->{_STATUS}) or $self->{_STATUS} == 0;    # <-- neither new, nor deleted nor modified
 
     if ( $self->_test_status(STATUS_NEW) && $self->_test_status(STATUS_DELETED) ) {
         $self->{_DATA} = {};
@@ -405,7 +405,7 @@ sub find {
     return 1;
 }
 
-# $Id: /local/cgi-session/trunk/lib/CGI/Session.pm 273 2006-02-16T03:30:35.734419Z mark  $
+# $Id: /local/cgi-session/trunk/lib/CGI/Session.pm 286 2006-03-09T03:07:01.898465Z mark  $
 
 =pod
 
@@ -1079,6 +1079,16 @@ Full name: B<CGI::Session::Serialize::storable>.
 L<freezethaw|CGI::Session::Serialize::freezethaw> - serializes data using L<FreezeThaw>. Requires L<FreezeThaw>.
 Full name: B<CGI::Session::Serialize::freezethaw>
 
+=item *
+
+L<yaml|CGI::Session::Serialize::yaml> - serializes data using YAML. Requires L<YAML> or L<YAML::Syck>.
+Full name: B<CGI::Session::Serialize::yaml>
+
+=item *
+
+L<json|CGI::Session::Serialize::json> - serializes data using JSON. Requires L<JSON::Syck>.
+Full name: B<CGI::Session::Serialize::json>
+
 =back
 
 =head2 ID GENERATORS
@@ -1109,7 +1119,7 @@ CGI::Session evolved to what it is today with the help of following developers.
 
 =over 4
 
-=item Andy Lester E<lt>alester@flr.follett.comE<gt>
+=item Andy Lester 
 
 =item Brian King E<lt>mrbbking@mac.comE<gt>
 
