@@ -1,25 +1,32 @@
 package CGI::Session::Driver::sqlite;
 
-# $Id: sqlite.pm 394 2008-03-22 02:35:30Z markstos $
+# $Id: /local/cgi-session/trunk/lib/CGI/Session/Driver/sqlite.pm 274 2006-03-02T02:53:47.269550Z mark  $
 
 use strict;
 
 use File::Spec;
 use base 'CGI::Session::Driver::DBI';
 use DBI qw(SQL_BLOB);
-use Fcntl;
 
-$CGI::Session::Driver::sqlite::VERSION    = '4.29_1';
+# @CGI::Session::Driver::sqlite::ISA        = qw( CGI::Session::Driver::DBI );
+$CGI::Session::Driver::sqlite::VERSION    = "1.2";
 
 sub init {
     my $self = shift;
 
-    unless ( $self->{Handle}) {
-       $self->{DataSource} = "dbi:SQLite:dbname=" . $self->{DataSource} unless ( $self->{DataSource} =~ /^dbi:sqlite/i );
+    $self->{DataSource} ||= File::Spec->catfile( File::Spec->tmpdir, 'sessions.sqlt' );
+    unless ( $self->{DataSource} =~ /^dbi:sqlite/i ) {
+        $self->{DataSource} = "dbi:SQLite:dbname=" . $self->{DataSource};
     }
 
-    $self->SUPER::init() or return;
-    
+    $self->{Handle} ||= DBI->connect( $self->{DataSource}, '', '', {RaiseError=>1, PrintError=>1, AutoCommit=>1});
+    unless ( $self->{Handle} ) {
+        return $self->set_error( "init(): couldn't create \$dbh: " . $DBI::errstr );
+    }
+    if (ref $self->{Handle} eq 'CODE') {
+        $self->{Handle} = $self->{Handle}->();
+    }
+    $self->{_disconnect} = 1;
     $self->{Handle}->{sqlite_handle_binary_nulls} = 1;
     return 1;
 }
@@ -31,50 +38,32 @@ sub store {
 
     my $dbh = $self->{Handle};
 
-    my $sth = $dbh->prepare("SELECT $self->{IdColName} FROM " . $self->table_name . " WHERE $self->{IdColName}=?");
+    my $sth = $dbh->prepare("SELECT id FROM " . $self->table_name . " WHERE id=?");
     unless ( defined $sth ) {
         return $self->set_error( "store(): \$sth->prepare failed with message " . $dbh->errstr );
     }
 
     $sth->execute( $sid ) or return $self->set_error( "store(): \$sth->execute failed with message " . $dbh->errstr );
     if ( $sth->fetchrow_array ) {
-        __ex_and_ret($dbh,"UPDATE " . $self->table_name . " SET $self->{DataColName}=? WHERE $self->{IdColName}=?",$datastr,$sid)
+        __ex_and_ret($dbh,"UPDATE " . $self->table_name . " SET a_session=? WHERE id=?",$datastr,$sid)
             or return $self->set_error( "store(): serialize to db failed " . $dbh->errstr );
     } else {
-        __ex_and_ret($dbh,"INSERT INTO " . $self->table_name . " ($self->{DataColName},$self->{IdColName}) VALUES(?, ?)",$datastr, $sid)
+        __ex_and_ret($dbh,"INSERT INTO " . $self->table_name . " (a_session,id) VALUES(?, ?)",$datastr, $sid)
             or return $self->set_error( "store(): serialize to db failed " . $dbh->errstr );
     }
     return 1;
 }
 
-sub DESTROY {
-    my $self = shift;
-
-    unless ( $self->{Handle} -> ping ) {
-        $self->set_error(__PACKAGE__ . '::DESTROY(). Database handle has gone away');
-        return;
-	}
-
-    unless ( $self->{Handle}->{AutoCommit} ) {
-        $self->{Handle}->commit;
-    }
-
-    if ( $self->{_disconnect} ) {
-        undef $self->{Handle};
-    }
-}
-
 sub __ex_and_ret {
     my ($dbh,$sql,$datastr,$sid) = @_;
-    # fix rt #18183
-    local $@;
     eval {
         my $sth = $dbh->prepare($sql) or return 0;
         $sth->bind_param(1,$datastr,SQL_BLOB) or return 0;
         $sth->bind_param(2,$sid) or return 0;
         $sth->execute() or return 0;
     };
-    return ! $@;
+    return 0 if $@;
+    return 1;
 }
 
 1;
@@ -89,19 +78,10 @@ CGI::Session::Driver::sqlite - CGI::Session driver for SQLite
 
 =head1 SYNOPSIS
 
-    $s = new CGI::Session("driver:sqlite", $sid, {DataSource=>'/my/folder/sessions.sqlt'});
+    $s = new CGI::Session("driver:sqlite", $sid);
+    $s = new CGI::Session("driver:sqlite", $sid, {DataSource=>'/tmp/sessions.sqlt'});
     $s = new CGI::Session("driver:sqlite", $sid, {Handle=>$dbh});
 
-or
-
-    $s = new CGI::Session('driver:sqlite', undef,
-    {
-        TableName=>'session',
-        IdColName=>'my_id',
-        DataColName=>'my_data',
-        Handle=>$dbh,
-    });
-
 =head1 DESCRIPTION
 
 B<sqlite> driver stores session data in SQLite files using L<DBD::SQLite|DBD::SQLite> DBI driver. More details see L<CGI::Session::Driver::DBI|CGI::Session::Driver::DBI>, its parent class.
@@ -112,7 +92,7 @@ Supported driver arguments are I<DataSource> and I<Handle>. B<At most> only one
 
 I<DataSource> should be in the form of C<dbi:SQLite:dbname=/path/to/db.sqlt>. If C<dbi:SQLite:> is missing it will be prepended for you. If I<Handle> is present it should be database handle (C<$dbh>) returned by L<DBI::connect()|DBI/connect()>.
 
-As of version 1.7 of this driver, the third argument is B<NOT> optional. Using a default database in the temporary directory is a security risk since anyone on the machine can create and/or read your session data. If you understand these risks and still want the old behavior, you can set the C<DataSource> option to I<'/tmp/sessions.sqlt'>.
+It's OK to drop the third argument to L<new()|CGI::Session::Driver/new()> altogether, in which case a database named F<sessions.sqlt> will be created in your machine's TEMPDIR folder, which is F</tmp> in UNIX.
 
 =head1 BUGS AND LIMITATIONS
 
