@@ -1,9 +1,9 @@
 package CGI::Session::ErrorHandler;
 
-# $Id: ErrorHandler.pm 216 2005-09-01 10:52:26Z sherzodr $
+# $Id: /local/cgi-session/trunk/lib/CGI/Session/ErrorHandler.pm 274 2006-03-02T02:53:47.269550Z mark  $
 
 use strict;
-$CGI::Session::ErrorHandler::VERSION = "4.01";
+$CGI::Session::ErrorHandler::VERSION = "4.04";
 
 =pod
 
@@ -38,10 +38,11 @@ Implicitly defines $pkg_name::errstr and sets its value to $message. Return valu
 =cut
 
 sub set_error {
-    my $class = shift;
+    my $class   = shift;
+    my $message = shift;
     $class = ref($class) || $class;
     no strict 'refs';
-    ${ "$class\::errstr" } = $_[0] || "";
+    ${ "$class\::errstr" } = sprintf($message || "", @_);
     return;
 }
 
